@@ -1,5 +1,7 @@
 from pyspark.accumulators import Accumulator
 
+LEN_ERROR = ValueError('x len should be equal to 2')
+
 
 class Ccf:
     class Iterate:
@@ -10,45 +12,47 @@ class Ccf:
         @staticmethod
         def _reduce(key, values, accumulator: Accumulator = None):
             value_list = []
-            to_return = []
             min_value = key
             for value in values:
                 if value < min_value:
                     min_value = value
                 value_list.append(value)
             if (min_value < key):
-                to_return.append((key, min_value))
+                yield (key, min_value)
                 for value in value_list:
                     if min_value != value:
-                        to_return.append((value, min_value))
+                        yield (value, min_value)
                         if accumulator:
                             accumulator.add(1)
-            return to_return
 
         @staticmethod
         def map(x):
-            return __class__._map(x[0], x[1])
+            if len(x) != 2:
+                raise LEN_ERROR
+            return __class__._map(*x)
 
         @staticmethod
         def reduce(x, accumulator: Accumulator = None):
-            return __class__._reduce(x[0], x[1], accumulator)
+            if len(x) != 2:
+                raise LEN_ERROR
+            yield from __class__._reduce(*x, accumulator)
 
     class IterateSecondarySorting(Iterate):
         @staticmethod
         def _reduce(key, values, accumulator: Accumulator = None):
             min_value = values[0]
-            to_return = []
             if min_value < key:
-                to_return.append((key, min_value))
+                yield (key, min_value)
                 for value in values[1:]:
-                    to_return.append((value, min_value))
+                    yield (value, min_value)
                     if accumulator:
                         accumulator.add(1)
-            return to_return
 
         @staticmethod
         def reduce(x, accumulator: Accumulator = None):
-            return __class__._reduce(x[0], x[1], accumulator)
+            if len(x) != 2:
+                raise LEN_ERROR
+            yield from __class__._reduce(*x, accumulator)
 
     class Dedup:
         @staticmethod
@@ -61,8 +65,12 @@ class Ccf:
 
         @staticmethod
         def map(x):
-            return __class__._map(x[0], x[1])
+            if len(x) != 2:
+                raise LEN_ERROR
+            return __class__._map(*x)
 
         @staticmethod
         def reduce(x):
-            return __class__._reduce(x[0], x[1])
+            if len(x) != 2:
+                raise LEN_ERROR
+            return __class__._reduce(*x)
