@@ -13,7 +13,8 @@ class CcfSpark:
                  sc: SparkContext,
                  secondary_sorting: bool = False,
                  graph: Graph = None,
-                 file_path: str = None):
+                 file_path: str = None,
+                 separator: str = ' '):
         self.sc = sc
         self.iterator = CCF_ITERATE_SECONDARY_SORTING if secondary_sorting else CCF_ITERATE
         self.secondary_sorting = secondary_sorting
@@ -23,12 +24,12 @@ class CcfSpark:
             # File line format expected : <int> <int>
             self.graph = sc.textFile(file_path).map(
                 lambda x: tuple(map(int,
-                                    x.split('  ')[:2])))
+                                    x.split(separator)[:2])))
         else:
             self.graph = sc.parallelize(
-                GraphGenerator.generate_random_graph(500, 350).edges)
+                GraphGenerator.generate_ccf_random_graph(500, 350).edges)
 
-    def iterate(self):
+    def iterate(self, with_distinct: bool = False):
         accumulator = self.sc.accumulator(0)
         iterator = self.iterator  # To avoid SPARK-5063 error.
         self.graph = self.graph.flatMap(iterator.map).groupByKey()
@@ -37,17 +38,18 @@ class CcfSpark:
         self.graph = self.graph.flatMap(
             lambda x, accumulator=accumulator: iterator.reduce(x, accumulator
                                                                )).sortByKey()
-        self.graph = self.graph.map(CCF_DEDUP.map).groupByKey()
-        self.graph = self.graph.map(CCF_DEDUP.reduce)
+        if with_distinct:
+            self.graph = self.graph.distinct()
+        else:
+            self.graph = self.graph.map(CCF_DEDUP.map).groupByKey()
+            self.graph = self.graph.map(CCF_DEDUP.reduce)
         return accumulator.value
 
-    def iterate_all(self):
+    def iterate_all(self, with_distinct: bool = False):
         while True:
-            new_pairs = self.iterate()
+            new_pairs = self.iterate(with_distinct)
             if not new_pairs:
                 break
 
     def print(self):
         return self.graph.collect()
-
-
